RouterSetter

Struct RouterSetter 

pub struct RouterSetter<R, Sw, Ex> { /* private fields */ }
Router editing environment.

You don’t need to understand this type, it’s here just for list it’s function. See Router document for api design and usage.

Implementations

Source

impl<R, Ex> RouterSetter<R, SetTableItem, Ex>
where R: RouterLike<Ex>,

pub fn endpoint(self) -> RouterSetter<Self, SetEndpoint, Ex>

Enter endpoint edit environment.

pub fn at<P: Into<Cow<'static, str>>>( self, path: P, ) -> RouterSetter<RouterSetter<Self, SetTableItem, Ex>, SetEndpoint, Ex>

Add a new item for path to router table and enter endpoint edit environment of that item.

pub fn fallback(self) -> RouterSetter<Self, SetFallback, Ex>

Enter fallback edit environment.

pub fn done(self) -> R
where Ex: Send + Sync + 'static,

Finish this router table editing.

Source

impl<R, Ex> RouterSetter<RouterSetter<R, SetTableItem, Ex>, SetEndpoint, Ex>
where R: RouterLike<Ex>, Ex: Send + Sync + 'static,

pub fn fallback( self, ) -> RouterSetter<RouterSetter<R, SetTableItem, Ex>, SetFallback, Ex>

Change to fallback editing environment.

pub fn at<P: Into<Cow<'static, str>>>( self, path: P, ) -> RouterSetter<RouterSetter<RouterSetter<R, SetTableItem, Ex>, SetTableItem, Ex>, SetEndpoint, Ex>

Change to inner router’s router table table editing environment.

pub fn is<M: Middleware<Ex> + 'static>(self, middleware: M) -> R

Finish setting uses middleware.

Source

impl<R, Sw, Ex> RouterSetter<R, Sw, Ex>
where R: RouterLike<Ex>, Sw: SetWhich<Ex>, Ex: Send + Sync + 'static,

pub fn method<M: Middleware<Ex> + 'static>( self, method: Method, middleware: M, ) -> R

Finish editing use a method router which accept method and uses middleware.

pub fn get<M: Middleware<Ex> + 'static>(self, middleware: M) -> R

A shortcut of self.method(Method::Get, middleware), see Self::method.

pub fn head<M: Middleware<Ex> + 'static>(self, middleware: M) -> R

A shortcut of self.method(Method::Head, middleware), see Self::method.

pub fn post<M: Middleware<Ex> + 'static>(self, middleware: M) -> R

A shortcut of self.method(Method::Post, middleware), see Self::method.

pub fn put<M: Middleware<Ex> + 'static>(self, middleware: M) -> R

A shortcut of self.method(Method::Put, middleware), see Self::method.

pub fn delete<M: Middleware<Ex> + 'static>(self, middleware: M) -> R

A shortcut of self.method(Method::Delete, middleware), see Self::method.

pub fn connect<M: Middleware<Ex> + 'static>(self, middleware: M) -> R

A shortcut of self.method(Method::Connect, middleware), see Self::method.

pub fn options<M: Middleware<Ex> + 'static>(self, middleware: M) -> R

A shortcut of self.method(Method::Options, middleware), see Self::method.

pub fn trace<M: Middleware<Ex> + 'static>(self, middleware: M) -> R

A shortcut of self.method(Method::Trace, middleware), see Self::method.

pub fn patch<M: Middleware<Ex> + 'static>(self, middleware: M) -> R

A shortcut of self.method(Method::Patch, middleware), see Self::method.

pub fn uses<M: Middleware<Ex> + 'static>(self, middleware: M) -> R

Finish editing use a middleware.