BuiltInExecutor

Struct BuiltInExecutor 

pub struct BuiltInExecutor;
Amiya built-in multi-thread async executor.

All instances of this type share one static executor under the hood. The inner executor starts N threads to run async task, N is count of your cpu cores.

In most case, you do not used this type directly, all created Amiya server have a instance of it by default.

Notice

If you disable the built-in-executor default feature, you need to call Amiya::executor() with your custom executor. Otherwise Amiya::listen() will not compile.